@@ -1,7 +1,7 @@
 /*
  *  eCoach
  *
- *  Copyright (C) 2008  Jukka Alasalmi
+ *  Copyright (C) 2009  Jukka Alasalmi, Sampo Savola
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  *****************************************************************************/
 #define GFXDIR DATADIR		"/pixmaps/" PACKAGE_NAME "/"
 #define ANALYZER_VIEW_HEIGHT	325
-#define ANALYZER_VIEW_WIDTH	650
+#define ANALYZER_VIEW_WIDTH	760
 
 /*****************************************************************************
  * Includes                                                                  *
@@ -41,6 +41,8 @@
 /* Hildon */
 #include <hildon/hildon-file-chooser-dialog.h>
 #include <hildon/hildon-file-system-model.h>
+#include <hildon/hildon.h>
+#include <hildon/hildon-pannable-area.h>
 
 /* Location */
 #include "location-distance-utils-fix.h"
@@ -51,7 +53,8 @@
 #include "ec-button.h"
 #include "ec_error.h"
 #include "util.h"
-
+/*osm-gps-map*/
+#include "osm_gps_map/osm-gps-map.h"
 #include "debug.h"
 
 /*****************************************************************************
@@ -66,7 +69,7 @@ typedef enum _AnalyzerViewUnitType {
 
 typedef enum
 {
-	METRIC, 
+	METRIC,
  	ENGLISH
 } MeasureUnit;
 /*****************************************************************************
@@ -78,6 +81,7 @@ typedef struct _AnalyzerViewTrack {
 	gchar *name;
 	gchar *comment;
 	gint number;
+	gchar *min_per_km;
 
 	/** @brief A list to pointers of type AnalyzerViewTrackSegment */
 	GSList *track_segments;
@@ -85,7 +89,7 @@ typedef struct _AnalyzerViewTrack {
 	/* These are analyzed from the data */
 
 	/** @brief Has the data been calculated */
-	gboolean data_is_analyzed; 
+	gboolean data_is_analyzed;
 
 	/** @brief Start time of the track */
 	struct timeval start_time;
@@ -311,6 +315,18 @@ static void analyzer_view_btn_track_prev_clicked(
 static void analyzer_view_btn_track_next_clicked(
 		GtkWidget *button,
 		gpointer user_data);
+		
+		
+/**
+ * @brief Callback for map button clicked signal
+ *
+ * @param button Button that was clicked
+ * @param user_data Pointer to #AnalyzerView
+ */
+static void analyzer_view_btn_map_clicked(
+		GtkWidget *button,
+		gpointer user_data);
+
 
 /**
  * @brief Get a file name using Hildon file chooser dialog
@@ -532,7 +548,7 @@ static void analyzer_view_draw_heart_rate(
 		gdouble pixels_per_unit);
 
 static void analyzer_view_set_units(AnalyzerView *self);
-
+static void create_map(gpointer user_data);
 
 /**
  * @brief Free memory used by a #AnalyzerViewTrack
@@ -540,7 +556,8 @@ static void analyzer_view_set_units(AnalyzerView *self);
  * @param track Pointer to a track to be freed
  */
 static void analyzer_view_track_destroy(AnalyzerViewTrack *track);
-
+gboolean map_button_press_cb(GtkWidget *widget, GdkEventButton *event, gpointer user_data);
+gboolean map_button_release_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data);
 /*****************************************************************************
  * Function declarations                                                     *
  *****************************************************************************/
@@ -559,11 +576,12 @@ AnalyzerView *analyzer_view_new(
 	self = g_new0(AnalyzerView, 1);
 	self->parent_window = parent_window;
 	self->gconf_helper = gconf_helper;
-	
-	
+
+
 
 	self->main_widget = gtk_fixed_new();
 
+
 	self->btn_back = ec_button_new();
 	ec_button_set_label_text(EC_BUTTON(self->btn_back), _("Back"));
 
@@ -578,8 +596,8 @@ AnalyzerView *analyzer_view_new(
 	ec_button_set_btn_down_offset(EC_BUTTON(self->btn_back), 2);
 
 	gtk_widget_set_size_request(self->btn_back, 74, 59);
-	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_back,
-			708, 18);
+	//gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_back,
+	//		708, 18);
 
 	DEBUG_END();
 	return self;
@@ -598,6 +616,39 @@ void analyzer_view_set_default_folder(
 	DEBUG_END();
 }
 
+static GtkWidget *create_table ()
+{
+
+  GtkWidget *hbox;
+  GtkWidget *table;
+  GtkWidget *button;
+  char buffer[32];
+  int i, j;
+
+  /* create a table of 10 by 10 squares. */
+  table = gtk_table_new (20, 20, FALSE);
+
+  /* set the spacing to 10 on x and 10 on y */
+  gtk_table_set_row_spacings (GTK_TABLE (table), 2);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 2);
+
+  gtk_widget_show (table);
+
+  /* this simply creates a grid of toggle buttons on the table
+   * to demonstrate the scrolled window. */
+  for (i = 1; i < 20; i++)
+    for (j = 1; j < 20; j++) {
+      sprintf (buffer, "button (%d,%d)\n", i, j);
+      button = gtk_toggle_button_new_with_label (buffer);
+
+      gtk_table_attach_defaults (GTK_TABLE (table), button,
+                                 i, i+1, j, j+1);
+    }
+
+  return table;
+}
+
+
 void analyzer_view_show(AnalyzerView *self)
 {
 	gint i;
@@ -606,6 +657,16 @@ void analyzer_view_show(AnalyzerView *self)
 	g_return_if_fail(self != NULL);
 	DEBUG_BEGIN();
 
+	self->win = hildon_stackable_window_new ();
+	gtk_window_set_title ( GTK_WINDOW (self->win), "eCoach >Activity log");
+	gtk_widget_set_name(GTK_WIDGET(self->win), "mainwindow");
+
+	g_signal_connect (self->win, "destroy", G_CALLBACK (analyzer_view_hide), self);
+
+
+	self->main_table = gtk_table_new(5,2,TRUE);
+	
+
 	/* Open button */
 	self->btn_open = ec_button_new();
 	ec_button_set_bg_image(EC_BUTTON(self->btn_open),
@@ -618,6 +679,8 @@ void analyzer_view_show(AnalyzerView *self)
 	gtk_widget_set_size_request(self->btn_open, 74, 59);
 	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_open,
 			18, 18);
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table), self->btn_open, 0, 1, 0, 1);
+
 
 	g_signal_connect(G_OBJECT(self->btn_open), "clicked",
 			G_CALLBACK(analyzer_view_btn_open_clicked), self);
@@ -636,7 +699,7 @@ void analyzer_view_show(AnalyzerView *self)
 	gtk_widget_set_size_request(self->btn_track_prev, 74, 59);
 	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_track_prev,
 			98, 18);
-
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table), self->btn_track_prev, 1, 2, 0, 1);
 	g_signal_connect(G_OBJECT(self->btn_track_prev), "clicked",
 			G_CALLBACK(analyzer_view_btn_track_prev_clicked),
 			self);
@@ -655,7 +718,7 @@ void analyzer_view_show(AnalyzerView *self)
 	gtk_widget_set_size_request(self->btn_track_next, 74, 59);
 	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_track_next,
 			178, 18);
-
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table), self->btn_track_next, 2, 3, 0, 1);
 	g_signal_connect(G_OBJECT(self->btn_track_next), "clicked",
 			G_CALLBACK(analyzer_view_btn_track_next_clicked),
 			self);
@@ -666,90 +729,45 @@ void analyzer_view_show(AnalyzerView *self)
 			260, 20);
 	gtk_widget_set_size_request(self->lbl_track_number,
 			150, 55);
-
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table), self->lbl_track_number, 3, 4, 0, 1);
 	/* Track details */
 	self->lbl_track_details = gtk_label_new(_("No track information "
-				"avail."));
+				"available "));
 	gtk_fixed_put(GTK_FIXED(self->main_widget), self->lbl_track_details,
 			420, 20);
-	gtk_widget_set_size_request(self->lbl_track_details, 280, 55);
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table), self->lbl_track_details, 4, 5, 0, 1);
+	gtk_widget_set_size_request(self->lbl_track_details, 300, 55);
 	desc = pango_font_description_from_string("Nokia Sans 14");
 	gtk_widget_modify_font(self->lbl_track_details, desc);
 	pango_font_description_free(desc);
 
-	/* Previous view button */
-	self->btn_view_prev = ec_button_new();
-	ec_button_set_bg_image(EC_BUTTON(self->btn_view_prev),
+
+	
+	/* Map button */
+	
+	self->btn_map = ec_button_new();
+	ec_button_set_bg_image(EC_BUTTON(self->btn_map),
 			EC_BUTTON_STATE_RELEASED,
-			GFXDIR "ec_button_change_view_bg.png");
+			GFXDIR "ec_button_map.png");
+	ec_button_set_btn_down_offset(EC_BUTTON(self->btn_map), 2);
+	gtk_widget_set_size_request(self->btn_map, 74, 59);
+	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_map,
+			708, 18);
+	g_signal_connect(G_OBJECT(self->btn_map), "clicked",
+			G_CALLBACK(analyzer_view_btn_map_clicked),
+			self);
+			
 
-	ec_button_set_icon(EC_BUTTON(self->btn_view_prev),
-			GFXDIR "ec_icon_arrow_left.png");
-
-	ec_button_set_center_vertically(EC_BUTTON(self->btn_view_prev), TRUE);
-
-	gtk_widget_set_size_request(GTK_WIDGET(self->btn_view_prev),
-			49, 329);
-	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_view_prev,
-			18, 83);
-
-	ec_button_set_btn_down_offset(EC_BUTTON(self->btn_view_prev), 2);
-
-	g_signal_connect(G_OBJECT(self->btn_view_prev), "clicked",
-			G_CALLBACK(analyzer_view_prev), self);
-
-	/* Next view button */
-	self->btn_view_next = ec_button_new();
-	ec_button_set_bg_image(EC_BUTTON(self->btn_view_next),
-			EC_BUTTON_STATE_RELEASED,
-			GFXDIR "ec_button_change_view_bg.png");
-
-	ec_button_set_icon(EC_BUTTON(self->btn_view_next),
-			GFXDIR "ec_icon_arrow_right.png");
-
-	ec_button_set_center_vertically(EC_BUTTON(self->btn_view_next), TRUE);
-
-	gtk_widget_set_size_request(GTK_WIDGET(self->btn_view_next),
-			49, 329);
-	gtk_fixed_put(GTK_FIXED(self->main_widget), self->btn_view_next,
-			733, 83);
-
-	ec_button_set_btn_down_offset(EC_BUTTON(self->btn_view_next), 2);
-
-	g_signal_connect(G_OBJECT(self->btn_view_next), "clicked",
-			G_CALLBACK(analyzer_view_next), self);
-
-	/* Create the scroll area */
-	self->scrolled = gtk_scrolled_window_new(NULL, NULL);
-
-	gtk_scrolled_window_set_policy(
-			GTK_SCROLLED_WINDOW(self->scrolled),
-			GTK_POLICY_NEVER,
-			GTK_POLICY_NEVER);
-
-	gtk_widget_set_size_request(self->scrolled,
-			ANALYZER_VIEW_WIDTH, ANALYZER_VIEW_HEIGHT);
-
-	gtk_fixed_put(GTK_FIXED(self->main_widget), self->scrolled,
-			75, 85);
-
-	/* Create the fixed layout for the different views */
-	self->fixed_view = gtk_fixed_new();
-	gtk_widget_set_size_request(self->fixed_view,
-			2 * ANALYZER_VIEW_WIDTH,
-			ANALYZER_VIEW_HEIGHT);
-
-	gtk_scrolled_window_add_with_viewport(
-			GTK_SCROLLED_WINDOW(self->scrolled),
-			self->fixed_view);
-
-	/* Create the views */
+	self->data = gtk_table_new(1,2,TRUE);
+      /* Create the views */
 	self->views[ANALYZER_VIEW_INFO] =
 		analyzer_view_create_view_info(self);
 
 	self->views[ANALYZER_VIEW_GRAPHS] =
 		analyzer_view_create_view_graphs(self);
-
+	
+	create_map(self);
+		
 	for(i = 0; i < ANALYZER_VIEW_COUNT; i++)
 	{
 		gtk_widget_show_all(self->views[i]);
@@ -758,12 +776,51 @@ void analyzer_view_show(AnalyzerView *self)
 				ANALYZER_VIEW_WIDTH, ANALYZER_VIEW_HEIGHT);
 	}
 
-	gtk_fixed_put(GTK_FIXED(self->fixed_view),
-			self->views[ANALYZER_VIEW_INFO],
-			0, 0);
+	gtk_table_attach_defaults (GTK_TABLE (self->data), self->views[ANALYZER_VIEW_INFO], 0, 1, 0, 1);
+	gtk_table_attach_defaults (GTK_TABLE (self->data), self->views[ANALYZER_VIEW_GRAPHS], 1, 2, 0, 1);
 
-	gtk_widget_show_all(self->main_widget);	
+	self->pannable = hildon_pannable_area_new ();
+	gtk_widget_set_name(GTK_WIDGET(self->pannable), "mainwindow");
+	g_object_set (G_OBJECT(self->pannable),"mov-mode", HILDON_MOVEMENT_MODE_HORIZ );
 
+	//g_object_set (G_OBJECT (self->pannable),"low-friction-mode", TRUE);
+
+//	g_object_set (G_OBJECT (self->pannable),
+//               "deceleration", 0.01);
+
+	hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (self->pannable), self->data);
+
+	self->pan = gtk_table_new(1,1,TRUE);
+	GtkWidget *weight_event;;
+	weight_event = gtk_event_box_new ();
+
+
+	GdkColor black;
+	black.red = 0;
+	black.green = 0;
+	black.blue = 0;
+
+	gtk_widget_modify_bg(weight_event,0,&black);
+
+	gtk_widget_set_size_request(self->pannable,
+			762,
+			340);
+	gtk_container_add (GTK_CONTAINER (self->pan), self->pannable);
+	gtk_container_add (GTK_CONTAINER (weight_event), self->pan);
+
+	gtk_fixed_put(GTK_FIXED(self->main_widget), weight_event,
+			18, 85);
+
+
+	//gtk_table_attach_defaults (GTK_TABLE (self->main_table),self->pannable, 0,5, 1, 3);
+
+	gtk_container_add (GTK_CONTAINER (self->win),self->main_widget);
+
+
+	//gtk_widget_show_all(self->main_widget);
+
+	
+	gtk_widget_show_all(self->win);
 	self->current_view = 0;
 
 	DEBUG_END();
@@ -775,7 +832,7 @@ void analyzer_view_hide(AnalyzerView *self)
 	g_return_if_fail(self != NULL);
 	DEBUG_BEGIN();
 
-	analyzer_view_clear_data(self);
+	//analyzer_view_clear_data(self);
 
 	analyzer_view_destroy_widget(self, &self->btn_open);
 	analyzer_view_destroy_widget(self, &self->btn_track_prev);
@@ -789,11 +846,11 @@ void analyzer_view_hide(AnalyzerView *self)
 	 * widget is enough */
 	for(i = 0; i < ANALYZER_VIEW_COUNT; i++)
 	{
-		gtk_widget_destroy(self->views[i]);
+		//gtk_widget_destroy(self->views[i]);
 		self->views[i] = NULL;
 	}
 
-	analyzer_view_destroy_widget(self, &self->scrolled);
+	//analyzer_view_destroy_widget(self, &self->scrolled);
 
 	DEBUG_END();
 }
@@ -806,6 +863,9 @@ static GtkWidget *analyzer_view_create_view_info(AnalyzerView *self)
 {
 	gint i;
 
+
+
+
 	g_return_val_if_fail(self != NULL, NULL);
 	DEBUG_BEGIN();
 
@@ -815,8 +875,8 @@ static GtkWidget *analyzer_view_create_view_info(AnalyzerView *self)
 	self->info_labels[ANALYZER_VIEW_INFO_LABEL_NAME][0] =
 		gtk_label_new(_("Activity name"));
 
-	self->info_labels[ANALYZER_VIEW_INFO_LABEL_COMMENT][0] =
-		gtk_label_new(_("Comment"));
+/*	self->info_labels[ANALYZER_VIEW_INFO_LABEL_COMMENT][0] =
+		gtk_label_new(_("Comment"));*/
 
 	self->info_labels[ANALYZER_VIEW_INFO_LABEL_TIME_START][0] =
 		gtk_label_new(_("Start time"));
@@ -835,6 +895,9 @@ static GtkWidget *analyzer_view_create_view_info(AnalyzerView *self)
 
 	self->info_labels[ANALYZER_VIEW_INFO_LABEL_SPEED_MAX][0] =
 		gtk_label_new(_("Maximum speed"));
+		
+	self->info_labels[ANALYZER_VIEW_INFO_LABEL_MIN_PER_KM][0] =
+		gtk_label_new(_("Min/km"));
 
 	self->info_labels[ANALYZER_VIEW_INFO_LABEL_HEART_RATE_AVG][0] =
 		gtk_label_new(_("Average heart rate"));
@@ -845,7 +908,7 @@ static GtkWidget *analyzer_view_create_view_info(AnalyzerView *self)
 	for(i = 0; i < ANALYZER_VIEW_INFO_LABEL_COUNT; i++)
 	{
 		self->info_labels[i][1] = gtk_label_new(_("N/A"));
-	
+
 		gtk_misc_set_alignment(
 				GTK_MISC(self->info_labels[i][0]),
 				1, 0.5);
@@ -876,6 +939,7 @@ static GtkWidget *analyzer_view_create_view_graphs(AnalyzerView *self)
 
 	self->graphs_table = gtk_table_new(2, 3, FALSE);
 
+
 	/* Speed button */
 	self->show_speed = TRUE;
 	self->graphs_btn_speed = ec_button_new();
@@ -1204,7 +1268,7 @@ static void analyzer_view_btn_open_clicked(
 	}
 
 	analyzer_view_clear_data(self);
-
+	osm_gps_map_clear_gps(OSM_GPS_MAP(self->map));
 	parser_status = gpx_parser_parse_file(
 			file_name,
 			analyzer_view_gpx_parser_callback,
@@ -1326,6 +1390,107 @@ static void analyzer_view_btn_track_next_clicked(
 	DEBUG_END();
 }
 
+static void create_map(gpointer user_data){
+
+ AnalyzerView *self = (AnalyzerView *)user_data;
+ self->map_win = hildon_stackable_window_new ();
+ g_signal_connect(self->map_win, "delete-event", G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+self->zoom_in =   gdk_pixbuf_new_from_file(GFXDIR "ec_map_zoom_in.png",NULL);
+self->zoom_out = gdk_pixbuf_new_from_file(GFXDIR "ec_map_zoom_out.png",NULL);
+ self->map_provider = (OsmGpsMapSource_t)gconf_helper_get_value_int_with_default(self->gconf_helper,MAP_SOURCE,1);
+ if(self->map_provider==0)
+ {
+   self->map_provider = (OsmGpsMapSource_t)1;
+  }
+  self->friendly_name = osm_gps_map_source_get_friendly_name(self->map_provider);
+  self->cachedir = g_build_filename(
+                        g_get_user_cache_dir(),
+                        "osmgpsmap",
+			self->friendly_name,
+                        NULL);
+  self->fullpath = TRUE;
+  self->map = (GtkWidget*)g_object_new (OSM_TYPE_GPS_MAP,
+                        "map-source",(OsmGpsMapSource_t)self->map_provider,
+                        "tile-cache",self->cachedir,
+                        "tile-cache-is-full-path",self->fullpath,
+                        "proxy-uri",g_getenv("http_proxy"),
+                        NULL);
+  g_free(self->cachedir);
+  osm_gps_map_add_button((OsmGpsMap*)self->map,0, 150, self->zoom_out);
+  osm_gps_map_add_button((OsmGpsMap*)self->map,720, 150, self->zoom_in);
+  	g_signal_connect (self->map, "button-press-event",
+                      G_CALLBACK (map_button_press_cb),self);
+ 	g_signal_connect (self->map, "button-release-event",
+                    G_CALLBACK (map_button_release_cb), self);
+  gtk_container_add (GTK_CONTAINER (self->map_win),self->map);
+  
+}
+gboolean
+map_button_release_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+
+     AnalyzerView *self = (AnalyzerView *)user_data;
+     if(user_data == NULL){ return FALSE;}
+      DEBUG_BEGIN();
+    float lat,lon;
+   // GtkEntry *entry = GTK_ENTRY(user_data);
+    OsmGpsMap *map = OSM_GPS_MAP(widget);
+
+    g_object_get(map, "latitude", &lat, "longitude", &lon, NULL);
+    DEBUG_END();
+    return FALSE;
+
+
+    }
+
+gboolean map_button_press_cb(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+      AnalyzerView *self = (AnalyzerView *)user_data;
+      int zoom = 0;
+      coord_t coord;
+      if(user_data ==NULL){
+	return FALSE;}
+      DEBUG_BEGIN();
+      
+       OsmGpsMap *map = OSM_GPS_MAP(widget);
+       
+ if ( (event->button == 1) && (event->type == GDK_BUTTON_PRESS) )
+    {
+      coord = osm_gps_map_get_co_ordinates(map, (int)event->x, (int)event->y);
+      	if(event->x < 80 && (event->y > 150 && event->y < 240)){
+
+	  DEBUG("ZOOM OUT");
+	    g_object_get(self->map, "zoom", &zoom, NULL);
+	    osm_gps_map_set_zoom((OsmGpsMap*)self->map, zoom-1);
+	}
+
+	 if(event->x > 720 && (event->y > 150 && event->y < 240)){
+	DEBUG("ZOOM IN");
+	g_object_get(self->map, "zoom", &zoom, NULL);
+	osm_gps_map_set_zoom((OsmGpsMap*)self->map, zoom+1);
+	}
+      
+    }
+ 
+      DEBUG_END();
+       return FALSE;
+}
+
+static void analyzer_view_btn_map_clicked(
+		GtkWidget *button,
+		gpointer user_data)
+{
+  AnalyzerViewTrack *track = NULL;
+  AnalyzerView *self = (AnalyzerView *)user_data;
+
+  DEBUG_BEGIN();
+  
+
+  gtk_widget_show_all(self->map_win);
+  osm_gps_map_set_mapcenter(OSM_GPS_MAP(self->map),self->lat, self->lon,14);
+  DEBUG_END();
+  
+}
 static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 {
 	HildonFileSystemModel *fs_model = NULL;
@@ -1350,15 +1515,14 @@ static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 		return NULL;
 	}
 
+	self->default_folder_name = gconf_helper_get_value_string_with_default(self->gconf_helper,ECGC_DEFAULT_FOLDER,"/home/user/MyDocs");
 	file_dialog = hildon_file_chooser_dialog_new_with_properties(
 			GTK_WINDOW(self->parent_window),
 			"file_system_model", fs_model,
 			"action", GTK_FILE_CHOOSER_ACTION_OPEN,
 			NULL);
 
-	gtk_file_chooser_set_current_folder(
-			GTK_FILE_CHOOSER(file_dialog),
-			self->default_folder_name);
+
 
 	file_filter = gtk_file_filter_new();
 	gtk_file_filter_set_name(file_filter, _("GPX files"));
@@ -1371,6 +1535,9 @@ static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 	gtk_file_chooser_set_filter(
 			GTK_FILE_CHOOSER(file_dialog),
 			file_filter);
+	gtk_file_chooser_set_current_folder(
+			GTK_FILE_CHOOSER(file_dialog),
+			self->default_folder_name);
 
 	gtk_widget_show_all(file_dialog);
 	result = gtk_dialog_run(GTK_DIALOG(file_dialog));
@@ -1382,19 +1549,21 @@ static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 		DEBUG_END();
 		return NULL;
 	}
+    /*** TODO proper maemo5 filechooser implementation ***/
 
+/*
 	gconf_helper_set_value_string(
 			self->gconf_helper,
 			ECGC_DEFAULT_FOLDER,
 			gtk_file_chooser_get_current_folder(
 				GTK_FILE_CHOOSER(file_dialog)));
-
+*/
 	file_name = gtk_file_chooser_get_filename(
 			GTK_FILE_CHOOSER(file_dialog));
 
 	gtk_widget_destroy(file_dialog);
 	//analyzer_view_set_units(self);
-	if (gconf_helper_get_value_bool_with_default(self->gconf_helper, 
+	if (gconf_helper_get_value_bool_with_default(self->gconf_helper,
 	    USE_METRIC, TRUE))
 	{
 		self->metric=TRUE;
@@ -1403,7 +1572,7 @@ static gchar *analyzer_view_choose_file_name(AnalyzerView *self)
 	{
 		self->metric=FALSE;
 	}
-	
+
 	DEBUG_END();
 	return file_name;
 }
@@ -1506,7 +1675,7 @@ static void analyzer_view_add_track(
 	self->tracks = g_slist_prepend(self->tracks, track);
 
 	track->name = g_strdup(parser_track->name);
-	track->comment = g_strdup(parser_track->comment);
+//	track->comment = g_strdup(parser_track->comment);
 	track->number = parser_track->number;
 
 	/* All other data is initialized correctly with g_new0 */
@@ -1554,6 +1723,10 @@ static void analyzer_view_add_track_point(
 	}
 
 	track_segment = (AnalyzerViewTrackSegment *)track->track_segments->data;
+
+	osm_gps_map_draw_gps(OSM_GPS_MAP(self->map),parser_waypoint->latitude,parser_waypoint->longitude,0);
+	self->lat = parser_waypoint->latitude;
+	self->lon = parser_waypoint->longitude;
 	waypoint = g_new0(AnalyzerViewWaypoint, 1);
 
 	/* Copy the data from the parser waypoint to the analyzer view
@@ -1681,8 +1854,18 @@ static void analyzer_view_analyze_track(
 	{
 		DEBUG("Secs: %f; distance: %f", secs, track->distance);
 		track->speed_avg = track->distance / secs * 3.6;
+		
+//		DEBUG("KULUNEET SEKUNTIT %d", result.tv_sec);
+//		DEBUG("KULUNUT MATKA %f", travelled_distance);
+	gdouble mins,seconds;
+	gdouble minkm = (secs / (track->distance/1000)/60);
+	seconds = modf(minkm,&mins);
+	DEBUG("MIN / KM  %02.f:%02.f ",mins,(60*seconds));
+	
+	track->min_per_km = g_strdup_printf(_("%02.f:%02.f"),mins,(60*seconds));
 	}
-
+	
+	
 	track->data_is_analyzed = TRUE;
 
 	DEBUG_END();
@@ -1846,7 +2029,7 @@ static void analyzer_view_analyze_track_segment(
 				speed_temp = dist_sum / time_sum * 3.6;
 				speed_temp = speed_temp * 0.621;
 				}
-			
+
 
 				for(temp2 = track_segment->track_points;
 				    temp2 != temp;
@@ -1915,7 +2098,7 @@ static void analyzer_view_analyze_track_segment(
 		}
 		else
 		{
-			speed_temp = dist_sum / time_sum * 3.6;	
+			speed_temp = dist_sum / time_sum * 3.6;
 			speed_temp = speed_temp * 0.621;
 		}
 
@@ -1980,7 +2163,7 @@ static void analyzer_view_analyze_track_segment_heart_rates(
 	track->heart_rate_max = G_MININT;
 
 	for(temp = track_segment->heart_rates; temp; temp = g_slist_next(temp))
-	{	
+	{
 		heart_rate = (AnalyzerViewHeartRate *)temp->data;
 
 		if(first)
@@ -2017,7 +2200,7 @@ static void analyzer_view_analyze_track_segment_heart_rates(
 		} else if(heart_rate->value < track->heart_rate_min) {
 			track->heart_rate_min = heart_rate->value;
 		}
-	
+
 		track->heart_rate_sum += heart_rate->value;
 		track->heart_rate_count++;
 	}
@@ -2050,7 +2233,7 @@ static void analyzer_view_show_track_information(
 	gdouble temp_average;
 	gdouble temp_distance;
 
-	
+
 	g_return_if_fail(self != NULL);
 	g_return_if_fail(track != NULL);
 
@@ -2072,12 +2255,13 @@ static void analyzer_view_show_track_information(
 		gtk_label_set_text(GTK_LABEL(self->info_labels
 				[ANALYZER_VIEW_INFO_LABEL_NAME][1]),
 				track->name);
+	gtk_window_set_title ( GTK_WINDOW (self->map_win), track->name);	
 	} else {
 		gtk_label_set_text(GTK_LABEL(self->info_labels
 				[ANALYZER_VIEW_INFO_LABEL_NAME][1]),
 				_("N/A"));
 	}
-
+/*
 	if((track->comment != NULL) && (strcmp(track->comment, "") != 0))
 	{
 		has_comment = TRUE;
@@ -2089,6 +2273,7 @@ static void analyzer_view_show_track_information(
 				[ANALYZER_VIEW_INFO_LABEL_COMMENT][1]),
 				_("N/A"));
 	}
+*/
 
 	if(has_name && has_comment)
 	{
@@ -2124,7 +2309,7 @@ static void analyzer_view_show_track_information(
 	} else {
 		buffer = buffer2;
 	}
-	
+
 	gtk_label_set_text(GTK_LABEL(self->lbl_track_details), buffer);
 
 	g_free(buffer);
@@ -2190,10 +2375,10 @@ static void analyzer_view_show_track_information(
 				[ANALYZER_VIEW_INFO_LABEL_DURATION][1]),
 				_("N/A"));
 	}
-			
+
 	if(track->distance >= 10000.0)
 	{
-		
+
 		if(self->metric)
 		{
 			buffer = g_strdup_printf(
@@ -2202,14 +2387,14 @@ static void analyzer_view_show_track_information(
 		}
 		else
 		{
-		
+
 			buffer = g_strdup_printf(
 					_("%.1f mi"),
 					  (track->distance / 1000.0)*0.621);
 		}
 
 	} else if(track->distance >= 1000.0) {
-		
+
 		if(self->metric)
 		{
 		buffer = g_strdup_printf(_("%.2f km"),
@@ -2222,7 +2407,7 @@ static void analyzer_view_show_track_information(
 		}
 
 	} else if(track->distance >= 0) {
-		
+
 		if(self->metric)
 		{
 		buffer = g_strdup_printf(_("%d m"), (gint)track->distance);
@@ -2232,7 +2417,7 @@ static void analyzer_view_show_track_information(
 		temp_distance = track->distance * 3.280;
 		buffer = g_strdup_printf(_("%.0f ft"), temp_distance);
 		}
-			
+
 	} else {
 		buffer = g_strdup_printf(_("N/A"));
 	}
@@ -2261,8 +2446,23 @@ static void analyzer_view_show_track_information(
 			buffer);
 	g_free(buffer);
 
+	
+	if(track->min_per_km != NULL){
+	  
+	  gtk_label_set_text(GTK_LABEL(self->info_labels
+				[ANALYZER_VIEW_INFO_LABEL_MIN_PER_KM][1]),
+			track->min_per_km);
+	}
+	else
+	{
+	    gtk_label_set_text(GTK_LABEL(self->info_labels
+				[ANALYZER_VIEW_INFO_LABEL_MIN_PER_KM][1]),
+			"N/A");
+	}
+	
+	
 	if(track->speed_max > 0.0)
-	{	
+	{
 		if(self->metric)
 		{
 		buffer = g_strdup_printf("%.1f km/h", track->speed_max);
@@ -2448,7 +2648,7 @@ static gboolean analyzer_view_graphs_drawing_area_exposed(
 		details.track = track;
 
 		details.show_speed = self->show_speed;
-	
+
 		details.show_altitude = (self->show_altitude &&
 				track->altitude_bounds_set);
 
@@ -2459,7 +2659,7 @@ static gboolean analyzer_view_graphs_drawing_area_exposed(
 		details.color_speed.g = .6;
 		details.color_speed.b = 1;
 		details.color_speed.a = 1;
-	
+
 		details.color_altitude.r = .4;
 		details.color_altitude.g = .9;
 		details.color_altitude.b = 0;
@@ -2582,16 +2782,16 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 
 	/* First, draw the titles of the scales */
 	if(self->metric)
-	{	
+	{
 	scale_text = _("Speed (km/h) Altitude (m) Heart rate (bpm)"
 		       "Time (hh:mm) (mm:ss)");
 	}
 	else
 	{
 	scale_text = _("Speed (mph) Altitude (ft) Heart rate (bpm)"
-			"Time (hh:mm) (mm:ss)");	
+			"Time (hh:mm) (mm:ss)");
 	}
-	
+
 	cairo_text_extents(cr, scale_text, &extents);
 
 	graph.height -= extents.height + 15;
@@ -2620,7 +2820,7 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 		}
 		else
 		{
-		scale_text = _("Speed (mph)");	
+		scale_text = _("Speed (mph)");
 		}
 		cairo_text_extents(cr, scale_text, &extents2);
 
@@ -2634,7 +2834,7 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 				extents.height / 2.0,
 				0, 2 * M_PI);
 		cairo_fill(cr);
-		
+
 		cairo_set_source_rgba(cr, 1, 1, 1, 1);
 		cairo_move_to(cr, extents.height + 5,
 				extents.height / 2.0 - extents.y_bearing / 2.0);
@@ -2650,7 +2850,7 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 		}
 		else
 		{
-		scale_text = _("Altitude (ft)");	
+		scale_text = _("Altitude (ft)");
 		}
 		cairo_text_extents(cr, scale_text, &extents2);
 
@@ -2665,7 +2865,7 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 				extents.height / 2.0,
 				0, 2 * M_PI);
 		cairo_fill(cr);
-		
+
 		cairo_set_source_rgba(cr, 1, 1, 1, 1);
 		cairo_move_to(cr, descr_x + extents.height + 5,
 				extents.height / 2.0 - extents.y_bearing / 2.0);
@@ -2689,7 +2889,7 @@ static GdkPixbuf *analyzer_view_create_pixbuf(
 				extents.height / 2.0,
 				0, 2 * M_PI);
 		cairo_fill(cr);
-		
+
 		cairo_set_source_rgba(cr, 1, 1, 1, 1);
 
 		cairo_move_to(cr, descr_x + extents.height + 5,
@@ -3173,12 +3373,12 @@ static void analyzer_view_draw_speed(
 {
 	/* Pixels per units ("how many pixels wide is a second") */
 	gdouble pixels_per_sec = 0;
-	
+
 	gdouble mile_speed = 0;
 
 	gdouble duration_secs = 0;
 	guint counter = 0;
-	
+
 	gdouble x = 0;
 	gdouble y = 0;
 
@@ -3236,15 +3436,15 @@ static void analyzer_view_draw_speed(
 			{
 				mile_speed  = 	waypoint->speed_averaged;
 			y = graph_area->height - mile_speed *
-				pixels_per_unit;	
-				
+				pixels_per_unit;
+
 			}
 
 			if(counter == 0)
 			{
 				cairo_move_to(cr, x, y);
 			} else {
-				x += pixels_per_sec * 
+				x += pixels_per_sec *
 				((gdouble)waypoint->time_to_prev.tv_sec +
 				 (gdouble)waypoint->time_to_prev.tv_usec /
 					 1000000.0);
@@ -3324,12 +3524,12 @@ static void analyzer_view_draw_altitude(
 
 			if(!first_point)
 			{
-				x += pixels_per_sec * 
+				x += pixels_per_sec *
 				((gdouble)waypoint->time_to_prev.tv_sec +
 				 (gdouble)waypoint->time_to_prev.tv_usec /
 					 1000000.0);
 			}
-	
+
 			if(!waypoint->altitude_is_set)
 			{
 				draw_line = FALSE;
@@ -3463,7 +3663,8 @@ static void analyzer_view_track_destroy(AnalyzerViewTrack *track)
 	DEBUG_BEGIN();
 
 	g_free(track->name);
-	g_free(track->comment);
+	g_free(track->min_per_km);
+//	g_free(track->comment);
 
 	for(temp = track->track_segments; temp; temp = g_slist_next(temp))
 	{
@@ -3503,12 +3704,12 @@ static void analyzer_view_set_units(AnalyzerView *self)
 					     METRIC,
 					     "English",
 	  				     ENGLISH,NULL);
-	
-	
+
+
 	do{
-		
+
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
-	
+
 		switch (result)
 		{
 			case METRIC:
@@ -3517,7 +3718,7 @@ static void analyzer_view_set_units(AnalyzerView *self)
 				break;
 			case ENGLISH:
 			self->metric = FALSE;
-			loop = FALSE;	
+			loop = FALSE;
 				break;
 		}
 	}while(loop);
